==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/kubernetes/api/model/TCPSocketActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class TCPSocketActionBuilder extends TCPSocketActionFluentImpl<TCPSocketActionBuilder> implements VisitableBuilder<TCPSocketAction,TCPSocketActionBuilder>{

    TCPSocketActionFluent<?> fluent;
    Boolean validationEnabled;

    public TCPSocketActionBuilder(){
            this(true);
    }
    public TCPSocketActionBuilder(Boolean validationEnabled){
            this(new TCPSocketAction(), validationEnabled);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent){
            this(fluent, true);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new TCPSocketAction(), validationEnabled);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent,TCPSocketAction instance){
            this(fluent, instance, true);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent,TCPSocketAction instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withPort(instance.getPort()); 
            this.validationEnabled = validationEnabled; 
    }
    public TCPSocketActionBuilder(TCPSocketAction instance){
            this(instance,true);
    }
    public TCPSocketActionBuilder(TCPSocketAction instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withPort(instance.getPort()); 
            this.validationEnabled = validationEnabled; 
    }

    public TCPSocketAction build(){
            TCPSocketAction buildable = new TCPSocketAction(fluent.getPort());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TCPSocketActionBuilder that = (TCPSocketActionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-4.9.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/TCPSocketActionBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TCPSocketActionBuilder extends TCPSocketActionFluentImpl<TCPSocketActionBuilder> implements VisitableBuilder<TCPSocketAction,TCPSocketActionBuilder>{

    TCPSocketActionFluent<?> fluent;
    Boolean validationEnabled;

    public TCPSocketActionBuilder(){
            this(true);
    }
    public TCPSocketActionBuilder(Boolean validationEnabled){
            this(new TCPSocketAction(), validationEnabled);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent){
            this(fluent, true);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new TCPSocketAction(), validationEnabled);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent,TCPSocketAction instance){
            this(fluent, instance, true);
    }
    public TCPSocketActionBuilder(TCPSocketActionFluent<?> fluent,TCPSocketAction instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withHost(instance.getHost()); 
            fluent.withPort(instance.getPort()); 
            this.validationEnabled = validationEnabled; 
    }
    public TCPSocketActionBuilder(TCPSocketAction instance){
            this(instance,true);
    }
    public TCPSocketActionBuilder(TCPSocketAction instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withHost(instance.getHost()); 
            this.withPort(instance.getPort()); 
            this.validationEnabled = validationEnabled; 
    }

    public TCPSocketAction build(){
            TCPSocketAction buildable = new TCPSocketAction(fluent.getHost(),fluent.getPort());
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TCPSocketActionBuilder that = (TCPSocketActionBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
